import { EventEmitter } from '@opensumi/events';
import { AppConfig, Disposable, IContextKeyService, IDisposable } from '@opensumi/ide-core-browser';
import { AbstractMenuService, IMenu, IMenuRegistry } from '@opensumi/ide-core-browser/lib/menu/next';
import { IStatusBarService, StatusBarEntry, StatusBarEntryAccessor } from '@opensumi/ide-core-browser/lib/services';
export declare class StatusBarService extends Disposable implements IStatusBarService {
    emitter: EventEmitter<{
        backgroundColor: [string?];
        color: [string?];
    }>;
    private background;
    private foreground;
    private entries;
    private commandService;
    protected readonly appConfig: AppConfig;
    protected readonly menuRegistry: IMenuRegistry;
    protected readonly menuService: AbstractMenuService;
    protected readonly globalContextKeyService: IContextKeyService;
    private layoutState;
    protected disposableCollection: Map<string, IDisposable>;
    constructor();
    /**
     * 获取背景颜色
     */
    getBackgroundColor(): string | undefined;
    getColor(): string | undefined;
    /**
     * 设置整个 Status Bar 背景颜色
     * @param color
     */
    setBackgroundColor(color?: string | undefined): void;
    /**
     * 设置 Status Bar 所有文字颜色，当设置值为 undefined 时，文件将回复原有颜色配置
     * @param color
     */
    setColor(color?: string | undefined): void;
    getElementConfig(entryId: string, entry: StatusBarEntry): StatusBarEntry;
    /**
     * 通过 id 获取关联的实例
     * @param id 状态栏 id
     * @returns
     */
    private getEntriesById;
    /**
     * 从 storage 中读取 state
     */
    private getStorageState;
    private setStorageState;
    /**
     * 设置一个 StatusBar Item
     * @param id
     * @param entry
     */
    addElement(entryId: string, entry: StatusBarEntry): StatusBarEntryAccessor;
    toggleElement(entryId: string): void;
    /**
     * 给指定 id 的元素设置属性
     * @param id
     * @param fields
     */
    setElement(entryId: string, fields: Partial<StatusBarEntry>): void;
    /**
     * 删除一个元素
     * @param id
     */
    removeElement(entryId: string): void;
    /**
     * 数组形式的 entries
     * @readonly
     * @private
     * @type {StatusBarEntry[]}
     * @memberof StatusBarService
     */
    get entriesArray(): StatusBarEntry[];
    /**
     * Status Bar 左边的 Item
     * @readonly
     * @type {StatusBarEntry[]}
     * @memberof StatusBarService
     */
    get leftEntries(): StatusBarEntry[];
    /**
     * Status Bar 右边的 Item
     *
     * @readonly
     * @type {StatusBarEntry[]}
     * @memberof StatusBarService
     */
    get rightEntries(): StatusBarEntry[];
    /**
     * command 转换 onClick 的方法
     * @param entry
     */
    private onclick;
    get contextKeyService(): import("@opensumi/ide-core-browser").IScopedContextKeyService;
    get contextMenu(): IMenu;
}
//# sourceMappingURL=status-bar.service.d.ts.map